@@ -7,6 +7,8 @@
 ### seqinfo
 ###
 
+### April 2020: Do we still need these 2 methods? Looks like their main
+### purpose was to support seqinfo() on RangedData objects.
 setMethod("seqinfo", "List", function(x) {
   si <- metadata(x)$seqinfo
   if (is.null(si)) {
@@ -25,12 +27,3 @@ setReplaceMethod("seqinfo", "List",
                    x
                  })
 
-setMethod("seqinfo", "RangedData",
-  function(x)
-  {
-    what <- "seqinfo() method for these objects"
-    .Defunct(msg=wmsg(IRanges:::RangedData_method_is_defunct_msg(what)))
-    seqinfo(ranges(x))
-  }
-)
-
